@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2021 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -38,7 +38,8 @@ class ActionsMenu(Gio.Menu):
         else:
             self.__object = Track(object.id)
         self.__set_save_action()
-        if self.__object.storage_type & StorageType.COLLECTION:
+        if self.__object.storage_type & StorageType.COLLECTION and\
+                not GLib.file_test("/app", GLib.FileTest.EXISTS):
             self.__set_open_action()
 
 #######################
