@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2021 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # Copyright (c) 2016 Gaurav Narula
 # Copyright (c) 2016 Felipe Borges <felipeborges@gnome.org>
 # Copyright (c) 2013 Arnel A. Borja <kyoushuu@yahoo.com>
@@ -21,7 +21,6 @@ from random import randint
 from lollypop.logger import Logger
 from lollypop.define import App, ArtSize, Repeat, Notifications
 from lollypop.objects_track import Track
-from lollypop.objects_radio import Radio
 
 
 class Server:
@@ -377,6 +376,7 @@ class MPRIS(Server):
             return "Stopped"
 
     def __update_metadata(self):
+        self.__metadata = {}
         if App().player.current_track.id is None or\
                 self.__get_status() == "Stopped":
             self.__metadata = {"mpris:trackid": GLib.Variant(
@@ -411,21 +411,13 @@ class MPRIS(Server):
             self.__metadata["xesam:url"] = GLib.Variant(
                 "s",
                 App().player.current_track.uri)
-            self.__rating = App().player.current_track.get_rate()
             self.__metadata["xesam:userRating"] = GLib.Variant(
                 "d",
-                self.__rating / 5)
-            if isinstance(App().player.current_track, Radio):
-                cover_path = App().art.get_radio_cache_path(
-                    App().player.current_track.name,
-                    ArtSize.MPRIS, ArtSize.MPRIS)
-            else:
-                cover_path = App().art.get_album_cache_path(
+                App().player.current_track.rate / 5)
+            cover_path = App().album_art.get_cache_path(
                     App().player.current_track.album,
                     ArtSize.MPRIS, ArtSize.MPRIS)
-            if cover_path is None:
-                self.__metadata["mpris:artUrl"] = GLib.Variant("s", "")
-            else:
+            if cover_path is not None:
                 self.__metadata["mpris:artUrl"] = GLib.Variant(
                     "s",
                     "file://" + cover_path)
