@@ -253,31 +253,35 @@ def escape(str, ignore=["_", "-", " ", "."]):
                     c.isdigit() or c in ignore]).rstrip()
 
 
-def get_lollypop_album_id(name, artists, year=None):
+def get_lollypop_album_id(name, artists, year=None, mbid=None):
     """
         Calculate Lollypop album id
         @param name as str
         @param artists as [str]
         @param year as int/None
+        @param mbid as str/None
     """
-    if year is None:
-        name = "%s_%s" % (sql_escape(" ".join(artists)), sql_escape(name))
-    else:
-        name = "%s_%s_%s" % (
-            sql_escape(" ".join(artists)), sql_escape(name), year)
+    name = "%s_%s" % (sql_escape(" ".join(artists)), sql_escape(name))
+    if year is not None:
+        name += "_%s" % year
+    if mbid is not None:
+        name += "_%s" % mbid
     return md5(name.encode("utf-8")).hexdigest()
 
 
-def get_lollypop_track_id(name, artists, album_name):
+def get_lollypop_track_id(name, artists, album_name, mbid=None):
     """
         Calculate Lollypop track id
         @param name as str
         @param artists as [str]
         @param year as str
         @param album_name as str
+        @param mbid as str/None
     """
     name = "%s_%s_%s" % (sql_escape(" ".join(artists)), sql_escape(name),
                          sql_escape(album_name))
+    if mbid is not None:
+        name += "_%s" % mbid
     return md5(name.encode("utf-8")).hexdigest()
 
 
